import 'package:flutter/material.dart';
import 'package:prod_scheduler_acc/constants.dart';
import 'package:prod_scheduler_acc/models/scheduler_user.dart';
import 'package:prod_scheduler_acc/scheduler_utils.dart';
import 'package:prod_scheduler_acc/screens/profile_screen.dart';
import 'package:prod_scheduler_acc/widgets/data_grid.dart';
import 'package:prod_scheduler_acc/widgets/navigation_drawer.dart';
import 'package:prod_scheduler_acc/widgets/user_profile.dart';

class PendingScreen extends StatefulWidget {
  static String id = 'pending_screen';
  final SchedulerUser _inputSchedulerUser;

  const PendingScreen({
    Key? key,
    required SchedulerUser inputSchedulerUser,
  })  : _inputSchedulerUser = inputSchedulerUser,
        super(key: key);

  @override
  State<PendingScreen> createState() => _PendingScreenState();
}

class _PendingScreenState extends State<PendingScreen> {
  int currentNavIndex = 0;
  bool showBottomNav = false;
  late SchedulerUser targetUser;

  @override
  void initState() {
    targetUser = widget._inputSchedulerUser;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    if (MediaQuery.of(context).size.width > kQptWidthBreakpoint) {
      showBottomNav = false;
    } else {
      showBottomNav = true;
    }
    return SafeArea(
      child: Scaffold(
        appBar: AppBar(
          backgroundColor: kQptColorLightGrey200,
          iconTheme: const IconThemeData(color: kQptColorTeal),
          title: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            mainAxisSize: MainAxisSize.max,
            children: [
              Visibility(
                visible: showBottomNav,
                child: const SizedBox(
                  width: 45,
                ),
              ),
              Flexible(
                flex: 7,
                child: Column(
                  children: [
                    Text(kQptAppBarHeader, style: Theme.of(context).textTheme.headlineSmall),
                    Text(kQptMainTitle, style: Theme.of(context).textTheme.titleLarge),
                  ],
                ),
              ),
            ],
          ),
          toolbarHeight: 60,
          elevation: 4,
          actions: [
            UserProfile(inputSchedulerUser: targetUser),
          ],
        ),
        drawer: !showBottomNav ? NavigationDrawer(inputSchedulerUser: targetUser) : null,
        body: Container(
          width: double.infinity,
          alignment: Alignment.center,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisSize: MainAxisSize.max,
            children: [
              Row(
                children: const [
                  Expanded(
                    flex: 2,
                    child: Padding(
                      padding: EdgeInsets.only(
                        top: 10,
                      ),
                      child: Text(
                        "Pending Services",
                        style: TextStyle(fontSize: 28, color: Colors.blueGrey, fontWeight: FontWeight.bold),
                        textAlign: TextAlign.center,
                      ),
                    ),
                  ),
                ],
              ),
              Row(
                children: [
                  Expanded(
                    flex: 13,
                    child: Padding(
                      padding: const EdgeInsets.only(
                        left: 20,
                        top: 10,
                        right: 20,
                      ),
                      child: Container(child: PendingGrid(inputCurrentUser: targetUser)),
                    ),
                  ),
                ],
              )
            ],
          ),
        ),
        bottomNavigationBar: showBottomNav
            ? BottomNavigationBar(
                currentIndex: currentNavIndex,
                backgroundColor: kQptColorPrimaryDarkTeal,
                selectedItemColor: Colors.white,
                unselectedItemColor: kQptColorLightGrey200,
                onTap: (index) async {
                  setState(() {
                    currentNavIndex = index;
                  });
                  switch (currentNavIndex) {
                    case 0:
                      {
                        /// PROFILE SCREEN
                        Navigator.popAndPushNamed(context, ProfileScreen.id);
                      }
                      break;
                    case 1:
                      {
                        /// ADD EVENT SCREEN
                        /// a lot of this came from this post:
                        /// https://letusflutter.com/2020/11/19/future-of-snackbars-scaffoldmessenger/
                        ScaffoldMessengerState scaffoldState = ScaffoldMessenger.of(context);

                        /// Open the Add Item Dialog
                        /// wait for the return....
                        final submitStatus = await SchedulerUtils.openCreateDialog(context, "${targetUser.fname} ${targetUser.lname}", true);
                        ScaffoldFeatureController scaffoldController = scaffoldState.showSnackBar(
                          SnackBar(
                            duration: const Duration(seconds: 1),
                            content: Text(submitStatus ?? "Closing the dialog from Pending..."),
                          ),
                        );
                      }
                      break;
                    default:
                      {
                        /// TODO: Locations Flyout
                      }
                      break;
                  }
                },
                items: const [
                  BottomNavigationBarItem(
                    label: "Profile",
                    icon: Icon(
                      Icons.person,
                      size: 20,
                    ),
                  ),
                  BottomNavigationBarItem(
                    tooltip: "Add a Pending Event",
                    label: "Add Pending Event",
                    icon: Icon(
                      Icons.add_circle,
                      color: Colors.amber,
                      size: 30,
                    ),
                  ),
                ],
              )
            : null,
        floatingActionButton: Padding(
          padding: const EdgeInsets.only(bottom: 5),
          child: FloatingActionButton(
            backgroundColor: kQptColorTeal,
            hoverColor: kQptColorPrimaryDarkTeal,
            tooltip: 'Add Pending Event',
            child: const Icon(Icons.add),
            onPressed: () async {
              /// ADD EVENT SCREEN
              /// a lot of this came from this post:
              /// https://letusflutter.com/2020/11/19/future-of-snackbars-scaffoldmessenger/
              ScaffoldMessengerState scaffoldState = ScaffoldMessenger.of(context);

              /// Open the Add Item Dialog
              /// wait for the return....
              final submitStatus = await SchedulerUtils.openCreateDialog(context, "${targetUser.fname} ${targetUser.lname},", true);
              final scaffoldController = scaffoldState.showSnackBar(
                SnackBar(
                  duration: const Duration(seconds: 1),
                  content: Text(submitStatus ?? "Closing the dialog from Pending..."),
                ),
              );

              /// now return to the main screen once the event has been created
              if (!mounted) return;
              Navigator.of(context).push(
                MaterialPageRoute(builder: (BuildContext context) => PendingScreen(inputSchedulerUser: targetUser)),
              );
            },
          ),
        ),
        floatingActionButtonLocation: FloatingActionButtonLocation.endDocked,
      ),
    );
  }
}
